@@ -44,7 +44,7 @@ class Domoticz(IPlugin):
 		for rs in self.configuration_plugin['param_dz']:
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
-				log.msg("index trouvé :  %s" % (idex))
+#				log.msg("index trouvé :  ***")
 				bodies == rs['boy']
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
 				log.msg("resp  :  %s" % (resp))
